@@ -995,7 +995,15 @@ class GTK_Main(object):
     def _play_file(self, filename, pause_on_load=False):
         player.stop()
 
-        player.playlist.load( os.path.abspath(filename) )
+        if '://' not in filename:
+            filename = os.path.abspath(filename)
+
+        # now THAT's what I call kludgy workaround
+        #                       -- thp, 2010-03-11
+        if filename.startswith('/http:/'):
+            filename = filename.replace('/http:/', 'http://')
+
+        player.playlist.load(filename)
         if player.playlist.is_empty:
             return False
 
