@@ -147,7 +147,10 @@ class panucciPlayer(ObservableService):
             self.__log.info( 'Using plain-old playbin.' )
             self.__player = gst.element_factory_make('playbin2', 'player')
             self.__volume_control = self.__player
-            self.__player.set_property( 'uri', 'file://' + filepath )
+            if filepath.startswith('/'):
+                self.__player.set_property('uri', 'file://' + filepath)
+            else:
+                self.__player.set_property('uri', filepath)
 
         bus = self.__player.get_bus()
         bus.add_signal_watch()
